@@ -184,11 +184,11 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   image=AcquireImage(image_info,exception);
   (void) ResetImagePage(image,"0x0+0+0");
   if ((image->columns != 0) && (image->rows != 0))
@@ -373,7 +373,7 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
           error->message,"`%s'",image_info->filename);
       pango_layout_set_markup(layout,caption,-1);
     }
-  if (draw_info->interline_spacing > 0)
+  if (draw_info->interline_spacing != 0)
     pango_layout_set_spacing(layout,ScalePangoValue(
       draw_info->interline_spacing,image->resolution.x));
   pango_layout_context_changed(layout);
@@ -384,22 +384,24 @@ static Image *ReadPANGOImage(const ImageInfo *image_info,
   if (image->columns == 0)
     {
       pango_layout_get_extents(layout,NULL,&extent);
-      image->columns=(extent.x+extent.width+PANGO_SCALE/2)/PANGO_SCALE+2*page.x;
+      image->columns=(size_t) ((extent.x+extent.width+PANGO_SCALE/2)/
+        PANGO_SCALE+2*page.x);
     }
   else
     {
-      image->columns-=2*page.x;
+      image->columns=(size_t) ((ssize_t) image->columns-2*page.x);
       pango_layout_set_width(layout,ScalePangoValue((double) image->columns,
         image->resolution.x));
     }
   if (image->rows == 0)
     { 
       pango_layout_get_extents(layout,NULL,&extent);
-      image->rows=(extent.y+extent.height+PANGO_SCALE/2)/PANGO_SCALE+2*page.y;
+      image->rows=(size_t) ((extent.y+extent.height+PANGO_SCALE/2)/
+        PANGO_SCALE+2*page.y);
     }
   else
     {
-      image->rows-=2*page.y;
+      image->rows=(size_t) ((ssize_t) image->rows-2*page.y);
       pango_layout_set_height(layout,ScalePangoValue((double) image->rows,
         image->resolution.y));
     }
